/*
    HighlighterKit.h

    Master include file for the HighlighterKit framework.

    Copyright (C) 2006, 2007, 2008, 2012  Saso Kiselkov

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifndef _HIGHLIGHTERKIT_H_
#define _HIGHLIGHTERKIT_H_

#import <HighlighterKit/HKSyntaxDefinition.h>
#import <HighlighterKit/HKSyntaxHighlighter.h>
#import <HighlighterKit/HKTextPattern.h>

#endif // _HIGHLIGHTERKIT_H_
